@@ -2,7 +2,7 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.9"
+__version__ = "0.0.10"
 
 # environment variables
 from .front import ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, ENV_DSLIBRARY_TOKEN
@@ -110,4 +110,6 @@ get_uri = _DEFAULT.get_uri
 get_last_metric = _DEFAULT.get_last_metric
 load_pickled_model = _DEFAULT.load_pickled_model
 save_pickled_model = _DEFAULT.save_pickled_model
+get_filesystem_connection = _DEFAULT.get_filesystem_connection
+install_pacakges = _DEFAULT.install_packages
 # TODO there may be more methods to add here
