@@ -20,6 +20,7 @@ from .utils.connect import connect_to_database
 from .utils.dbconn import sql_enquote_id
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, find_url_extension
 from .utils.nosql import connect_to_nosql
+from .utils.packages import install_packages
 
 try:
     import mlflow
@@ -508,6 +509,16 @@ class DSLibrary(object):
             return mlflow.active_run()
         return self._mlflow_run
 
+    def install_packages(self, packages: list, verbose: bool=False):
+        """
+        Install packages.  Does a local 'pip install' by default but can be overridden to interact with different
+        virtual environment managers.
+
+        :param packages:  An iterable of package names, with optional qualifiers like "pandas==1.1.5"
+        :param verbose:   By default we inhibit most output.
+        """
+        return install_packages(packages, verbose=verbose)
+
     def _write_content(self, opener, resource_name: str, content, append: bool=False, **kwargs):
         """
         Fully write various types of content.
