@@ -228,7 +228,7 @@ class ModelRunner(object):
                 if venv_py:
                     cmd[0] = venv_py
         else:
-            folder = self.project_root or os.path.split(path)[0]
+            folder = self.project_root or os.path.split(path)[0] or "."
         # if we're not using metadata we have to infer how to execute the code
         if not cmd:
             cmd = self.infer_command_from_path(path)
