@@ -168,3 +168,11 @@ class DSLibraryViaMMLibrary(DSLibrary):
             else:
                 raise DSLibraryException("The 'database' parameter is not supported by this implementation of get_db_connection()")
         return method(resource_name, **params)
+
+    def install_packages(self, packages: list, verbose: bool=False):
+        method = self._find_method("install_packages")
+        sig = inspect.signature(method)
+        if method:
+            return method(packages)
+        else:
+            return super(DSLibraryViaMMLibrary, self).install_packages(packages, verbose)
